@@ -3,13 +3,13 @@ import shutil
 from metaerg import context
 from metaerg.datatypes import sqlite
 
-def _run_programs(genome_name, contig_dict, db_connection, result_files):
-    cds_aa_file = context.spawn_file('cds.faa', genome_name)
+def _run_programs(genome, contig_dict, db_connection, result_files):
+    cds_aa_file = context.spawn_file('cds.faa', genome.name)
     with open(result_files[0], 'w') as output, open(cds_aa_file) as input:
         context.run_external('tmhmm', stdin=input, stdout=output)
 
 
-def _read_results(genome_name, contig_dict, db_connection, result_files) -> int:
+def _read_results(genome, contig_dict, db_connection, result_files) -> int:
     count = 0
     current_feature = None
     current_txt = ""
